@@ -1,7 +1,6 @@
 class.Rud <-
-function( cutscore, ip, irt.model = "dich", ability = NULL, se=NULL, rdm = NULL, quadrature=NULL){
-	
-	if(irt.model != "dich") stop("Code for non 3PL models not yet written")  	
+function( cutscore, ip, ability = NULL, se=NULL, rdm = NULL, quadrature=NULL){
+	 	
 		if(is.null(quadrature)==TRUE){
 		if(is.null(ability)==TRUE){
 			
@@ -19,7 +18,7 @@ function( cutscore, ip, irt.model = "dich", ability = NULL, se=NULL, rdm = NULL,
 			if(length(quadrature)!=2) stop("quadrature points and weights must be a list of legth 2")
 			if(length(quadrature[[1]])!=length(quadrature[[2]])) stop("number of quadrature points and weights do not match")
 			
-		se<-SEM(ip,quad[[1]])							
+		se<-SEM(ip,quadrature[[1]])							
 		results <- Rud.D(cutscore, quadrature, se)				
 	results}}
 
